/*!
 * \file javascript_file.h
 * \brief A Javascript file object to store information on a Javascript file in the RMS.
 *
 * A Javascript file object to store information on a Javascript file in the RMS.
 *
 * \author Russell Toris, WPI - rctoris@wpi.edu
 * \date December 30, 2012
 */

#ifndef JAVASCRIPT_FILE_H_
#define JAVASCRIPT_FILE_H_

#include <string>

/*!
 * \namespace rms
 * rms namespace for all RMS calls and objects
 */
namespace rms
{
/*!
 * \class javascript_file
 * \brief A Javascript file object to store information on a Javascript file in the RMS.
 *
 * A Javascript file object to store information on a Javascript file in the RMS.
 */
class javascript_file
{
public:
  /*!
   * Create a Javascript file object with the given information.
   *
   * @param fileid the Javascript file ID number
   * @param url the remote URL of the Javascript file to be downloaded into RMS
   * @param path the local path of the file to save on the RMS server
   */
  javascript_file(int fileid, std::string url, std::string path);

  /*!
   * Get the Javascript file ID number.
   *
   * @return the Javascript file ID number
   */
  int get_fileid();
  /*!
   * Get the remote URL of the Javascript file to be downloaded into RMS.
   *
   * @return the the remote URL of the Javascript file to be downloaded into RMS
   */
  std::string get_url();
  /*!
   * Get the local path of the file to save on the RMS server.
   *
   * @return the local path of the file to save on the RMS server
   */
  std::string get_path();

private:
  int fileid; /*!< the file ID */
  std::string url, path; /*!< the remote URL and local path */
};
}

#endif
