/*!
 * \file article.h
 * \brief An article object to store information on an article in the RMS.
 *
 * An article account object to store information on an article in the RMS.
 *
 * \author Russell Toris, WPI - rctoris@wpi.edu
 * \date December 30, 2012
 */

#ifndef ARTICLE_H_
#define ARTICLE_H_

#include <string>

/*!
 * \namespace rms
 * rms namespace for all RMS calls and objects
 */
namespace rms
{
/*!
 * \class article
 * \brief An article account object to store information on an article in the RMS.
 *
 * An article account object to store information on an article in the RMS.
 */
class article
{
public:
  /*!
   * Create an article with the given information.
   *
   * @param artid the article ID number
   * @param title the title of the article
   * @param content the HTML content of the article
   * @param pageid the page ID this article belongs to
   * @param index the index on the page for this article
   */
  article(int artid, std::string title, std::string content, int pageid, int index);

  /*!
   * Get the article ID number.
   *
   * @return the article ID number
   */
  int get_artid();
  /*!
   * Get the title.
   *
   * @return the title
   */
  std::string get_title();
  /*!
   * Get the HTML content.
   *
   * @return the HTML content
   */
  std::string get_content();
  /*!
   * Get the page ID this article belongs to.
   *
   * @return the page ID this article belongs to
   */
  int get_pageid();
  /*!
   * Get the index on the page for this article.
   *
   * @return the index on the page for this article
   */
  int get_index();

private:
  int artid, pageid, index; /*!< the article ID, page ID, and page index */
  std::string title, content; /*!< the title and HTML content */
};
}

#endif
