/*!
 * \file content_page.h
 * \brief A content page object to store information on a content page in the RMS.
 *
 * A content page object to store information on a content page in the RMS.
 *
 * \author Russell Toris, WPI - rctoris@wpi.edu
 * \date December 30, 2012
 */

#ifndef CONTENT_PAGE_H_
#define CONTENT_PAGE_H_

#include <string>

/*!
 * \namespace rms
 * rms namespace for all RMS calls and objects
 */
namespace rms
{
/*!
 * \class content_page
 * \brief A content page object to store information on a content page in the RMS.
 *
 * A content page object to store information on a content page in the RMS.
 */
class content_page
{
public:
  /*!
   * Create a content page with the given information. A string value of "NULL" can be if Javascript file is a null value.
   *
   * @param pageid the content page ID number
   * @param title the title of the page
   * @param menu the name of the menu item for the page
   * @param index the index in the main menu for this page
   * @param js the name of the Javascript file to include with this
   */
  content_page(int pageid, std::string title, std::string menu, int index, std::string js);

  /*!
   * Get the content page ID number.
   *
   * @return the content page ID number
   */
  int get_pageid();
  /*!
   * Get the title.
   *
   * @return the title
   */
  std::string get_title();
  /*!
   * Get the name of the menu item for the page.
   *
   * @return the name of the menu item for the page
   */
  std::string get_menu();
  /*!
   * Get the index in the main menu for this page.
   *
   * @return the index in the main menu for this page
   */
  int get_index();
  /*!
   * Get the name of the Javascript file to include with this page or "NULL" if it was null.
   *
   * @return the name of the Javascript file to include with this page or "NULL" if it was null
   */
  std::string get_js();

private:
  int pageid, index; /*!< the page ID and menu index */
  std::string title, menu, js; /*!< the title, menu name, and Javascript file name */
};
}

#endif
