/*!
 * \file slide.h
 * \brief A slide object to store information about a slide in the RMS.
 *
 * A slide object to store information about a slide in the RMS.
 *
 * \author Russell Toris, WPI - rctoris@wpi.edu
 * \date December 30, 2012
 */

#ifndef SLIDE_H_
#define SLIDE_H_

#include <string>

/*!
 * \namespace rms
 * rms namespace for all RMS calls and objects
 */
namespace rms
{
/*!
 * \class slide
 * \brief A slide object to store information about a slide in the RMS.
 *
 * A slide object to store information about a slide in the RMS.
 */
class slide
{
public:
  /*!
   * Creates a slide with the given information.
   *
   * @param slideid the slide ID number
   * @param img the slide's image file name
   * @param caption the slide's caption
   * @param index the index in the slideshow
   */
  slide(int slideid, std::string img, std::string caption, int index);

  /*!
   * Get the slide ID number.
   *
   * @return the slide ID number
   */
  int get_slideid();
  /*!
   * Get the slide's image file name.
   *
   * @return the slide's image file name
   */
  std::string get_img();
  /*!
   * Get tthe slide's caption.
   *
   * @return the slide's caption
   */
  std::string get_caption();
  /*!
   * Get the index in the slideshow for this slide.
   *
   * @return the index in the slideshow
   */
  int get_index();

private:
  int slideid, index; /*!< the slide ID and index in the slideshow */
  std::string img, caption; /*!< the image file name and caption */
};
}

#endif
