/*!
 * \file experiment.h
 * \brief An experiment object to store information on an experiment entry in the RMS.
 *
 * An experiment object to store information on an experiment entry in the RMS.
 *
 * \author Russell Toris, WPI - rctoris@wpi.edu
 * \date December 30, 2012
 */

#ifndef EXPERIMENT_H_
#define EXPERIMENT_H_

#include <string>

/*!
 * \namespace rms
 * rms namespace for all RMS calls and objects
 */
namespace rms
{
/*!
 * \class study
 * \brief An experiment object to store information on an experiment entry in the RMS.
 *
 * An experiment object to store information on an experiment entry in the RMS.
 */
class experiment
{
public:
  /*!
   * Create an experiment with the given information.
   *
   * @param expid the experiment ID number
   * @param userid the user ID number for this experiment
   * @param condid the condition ID number for this experiment
   * @param envid the environment ID number for this experiment
   * @param start the start timestamp of the experiment in the form YYYY-MM-DD HH:MM:SS
   * @param end the end timestamp of the experiment in the form YYYY-MM-DD HH:MM:SS
   */
  experiment(int expid, int userid, int condid, int envid, std::string start, std::string end);

  /*!
   * Get the experiment ID number.
   *
   * @return the experiment ID number
   */
  int get_expid();
  /*!
   * Get the user ID number for this experiment.
   *
   * @return the user ID number for this experiment
   */
  int get_userid();
  /*!
   * Get the condition ID number for this experiment.
   *
   * @return the condition ID number for this experiment
   */
  int get_condid();
  /*!
   * Get the environment ID number for this experiment.
   *
   * @return the environment ID number for this experiment
   */
  int get_envid();
  /*!
   * Get the start timestamp of the experiment in the form YYYY-MM-DD HH:MM:SS.
   *
   * @return the start timestamp of the experiment in the form YYYY-MM-DD HH:MM:SS
   */
  std::string get_start();
  /*!
   * Get the end timestamp of the experiment in the form YYYY-MM-DD HH:MM:SS.
   *
   * @return the end timestamp of the experiment in the form YYYY-MM-DD HH:MM:SS
   */
  std::string get_end();

private:
  int expid, userid, condid, envid; /*!< the study, user, condition, and environment ID */
  std::string start, end; /*!< the start/end timestamp of the study */
};
}

#endif
