/*!
 * \file study.h
 * \brief A study object to store information on a study entry in the RMS.
 *
 * A study object to store information on a study entry in the RMS.
 *
 * \author Russell Toris, WPI - rctoris@wpi.edu
 * \date December 30, 2012
 */

#ifndef STUDY_H_
#define STUDY_H_

#include <string>

/*!
 * \namespace rms
 * rms namespace for all RMS calls and objects
 */
namespace rms
{
/*!
 * \class study
 * \brief A study object to store information on a study entry in the RMS.
 *
 * A study object to store information on a study entry in the RMS.
 */
class study
{
public:
  /*!
   * Create a study with the given information.
   *
   * @param studyid the study ID number
   * @param name the name of the study
   * @param description a description of the study
   * @param start the start date of the study in the form YYYY-MM-DD
   * @param end the end date of the study in the form YYYY-MM-DD
   */
  study(int studyid, std::string name, std::string description, std::string start, std::string end);

  /*!
   * Get the study ID number.
   *
   * @return the study ID number
   */
  int get_studyid();
  /*!
   * Get the name.
   *
   * @return the name
   */
  std::string get_name();
  /*!
   * Get the description.
   *
   * @return the description
   */
  std::string get_description();
  /*!
   * Get the start date of the study in the form YYYY-MM-DD.
   *
   * @return the start date of the study in the form YYYY-MM-DD
   */
  std::string get_start();
  /*!
   * Get the end date of the study in the form YYYY-MM-DD.
   *
   * @return the end date of the study in the form YYYY-MM-DD
   */
  std::string get_end();

private:
  int studyid; /*!< the study ID */
  std::string name, description, start, end; /*!< the name, description, and start/end date of the study */
};
}

#endif
