/*!
 * \file study_log.h
 * \brief A study_log object to store information on a study log entry in the RMS.
 *
 * A study_log object to store information on a study log entry in the RMS.
 *
 * \author Russell Toris, WPI - rctoris@wpi.edu
 * \date December 30, 2012
 */

#ifndef STUDY_LOG_H_
#define STUDY_LOG_H_

#include <string>

/*!
 * \namespace rms
 * rms namespace for all RMS calls and objects
 */
namespace rms
{
/*!
 * \class study_log
 * \brief A study_log object to store information on a study log entry in the RMS.
 *
 * A study_log object to store information on a study log entry in the RMS.
 */
class study_log
{
public:
  /*!
   * Create a study_log with the given information.
   *
   * @param logid the study log entry ID number
   * @param expid the experiment ID number for the log entry
   * @param timestamp the timestamp of the entry in the form YYYY-MM-DD HH:MM:SS
   * @param entry the log entry
   */
  study_log(int logid, int expid, std::string timestamp, std::string entry);

  /*!
   * Get the study log entry ID number.
   *
   * @return the the study log entry ID number
   */
  int get_logid();
  /*!
   * Get the experiment ID number for the log entry.
   *
   * @return the experiment ID number for the log entry
   */
  int get_expid();
  /*!
   * Get the timestamp of the entry in the form YYYY-MM-DD HH:MM:SS.
   *
   * @return the timestamp of the entry in the form YYYY-MM-DD HH:MM:SS
   */
  std::string get_timestamp();
  /*!
   * Get the the log entry.
   *
   * @return the log entry
   */
  std::string get_entry();

private:
  int logid, expid; /*!< the log and experiment ID numbers */
  std::string timestamp, entry; /*!< the timestamp and entry */
};
}

#endif
